PHdata: The 'PHdata' class

PHdataR Documentation

The PHdata class

Description

An object class containing time resolved 'peak-hopping' mass spectrometry data

Details

A list with the following items:

masses: a vector of strings denoting the isotopes monitored in each run
signals: a list with objects of class timeresolved, each corresponding to a detector (i.e. length(signals)==1 for single collector instruments).

See Also

loaddata


ArArRedux documentation built on July 21, 2026, 1:07 a.m.

Related to PHdata in ArArRedux...