averagebyday: Average all the data collected on the same day.

View source: R/average.R

averagebydayR Documentation

Average all the data collected on the same day.

Description

This function is useful for grouping a number of replicate air shots or calibration experiments

Usage

averagebyday(x, newlabel)

Arguments

x

an object of class timeresolved, logratios, PHdata or redux

newlabel

a string with the new label that should be given to the average

Value

an object of the same class as x

Examples

dfile <- system.file("Calibration.csv",package="ArArRedux")
dlabels <- c("H1","AX","L1","L2")
md <- loaddata(dfile,dlabels,PH=TRUE)
ld <- fitlogratios(blankcorr(md))
d <- averagebyday(ld,"DCAL")
plotcorr(d)

ArArRedux documentation built on July 21, 2026, 1:07 a.m.