Learn R Programming

ArArRedux (version 0.1)

fitlogratios: Extrapolation to 'time zero'

Description

This function extrapolates time resolved mass spectrometer data to t=0. When fed with multicollector data, it forms the ratios of the raw signals, forms their logs and performs linear regression to t=0 When fed with single collector data, the function first takes their logs and extrapolates them to t=0 before taking ratios, unless denmass=NULL, in which case the logs of the raw signals are extrapolated.

Usage

fitlogratios(x, ...)

## S3 method for class 'default': fitlogratios(x, ...)

## S3 method for class 'timeresolved': fitlogratios(x, denmass, ...)

## S3 method for class 'PHdata': fitlogratios(x, denmass = NULL, ...)

Arguments

x
an object of class timeresolved or PHdata
...
further arguments (see below)
denmass
a string denoting the denominator isotope

Value

  • an object of class logratios

Examples

Run this code
samplefile <- system.file("Samples.csv",package="ArArRedux")
masses <- c("Ar37","Ar38","Ar39","Ar40","Ar36")
m <- loaddata(samplefile,masses) # samples and J-standards
blanklabel <- "EXB#"
l <- fitlogratios(blankcorr(m,blanklabel),"Ar40")
plotcorr(l$covmat)

Run the code above in your browser using DataLab