getJfactors: Calculate the irradiation parameter ('J factor')

View source: R/J.R

getJfactorsR Documentation

Calculate the irradiation parameter ('J factor')

Description

Interpolate the irradiation parameters for the samples given the 40Ar*/39ArK ratios of the samples and fluence monitors

Usage

getJfactors(R)

Arguments

R

a vector of 40Ar*/39ArK ratios

Value

an object of class redux containing, as intercepts, the 40Ar*/39ArK ratios of the samples, the interpolated J-factors, and the 40K decay constant; and as covmat: the covariance matrix. All other class properties are inherited from R.

Examples

data(Melbourne)
R <- get4039(Melbourne$X,Melbourne$irr)
J <- getJfactors(R)
plotcorr(J)

ArArRedux documentation built on July 21, 2026, 1:07 a.m.