powered by
Calculate 40Ar/39Ar ages from a vector of 40Ar/39Ar-ratios and J-factors
getages(RJ)
an object of class results containing the ages and their covariance matrix
results
an object of class Redux containing the amalgamated \(^{40}\)Ar\(^*\)/\(^{39}\)Ar\(_K\)-ratios and J-factors with their covariance matrix
Redux
data(Melbourne) R <- get4039(Melbourne$X,Melbourne$irr) J <- getJfactors(R) ages <- getages(J) plotcorr(ages)
Run the code above in your browser using DataLab