Learn R Programming

ArArRedux (version 1.1)

getmasses: Select a subset of isotopes from a dataset

Description

Extracts the intercepts, covariance matrix, etc. of a selection of isotopes from a larger dataset

Usage

getmasses(x, ...)

# S3 method for default getmasses(x, ...)

# S3 method for timeresolved getmasses(x, mass, invert = FALSE, ...)

# S3 method for logratios getmasses(x, num, den, invert = FALSE, ...)

# S3 method for redux getmasses(x, num, den, invert = FALSE, ...)

Value

an object of the same class as x

Arguments

x

an object of class logratios, timeresolved, PHdata or redux.

...

other arguments

mass

a vector of strings denoting the masses of interest

invert

boolean parameter indicating whether the selection should be inverted (default = FALSE)

num

vector of strings indicating the numerator isotopes

den

vector of string indicating the denominator isotopes

Examples

Run this code
kfile <- system.file("K-glass.csv",package="ArArRedux")
masses <- c("Ar37","Ar38","Ar39","Ar40","Ar36")
mk <- loaddata(kfile,masses)
lk <- fitlogratios(blankcorr(mk,"EXB#","K:"),"Ar40")
k <- getmasses(lk,"Ar39","Ar40") # subset of the relevant isotopes
plotcorr(k)

Run the code above in your browser using DataLab