logratios: The 'logratios' class

logratiosR Documentation

The logratios class

Description

An object class containing logratio intercepts

Details

A list with the following items:

labels: a vector of strings denoting the names of the runs
num: a vector of strings denoting the numerator isotopes
den: a vector of strings denoting the denominator isotopes
intercepts: a vector of logratio intercepts or values
covmat: the covariance matrix of intercepts
irr: a vector of strings denoting the irradiation runs
pos: a vector of integers with the positions in the irradiation stack
thedate: a vector containing the acquisition dates and times
nlr: a vector with the number of logratios per run


ArArRedux documentation built on July 21, 2026, 1:07 a.m.