Learn R Programming

ArArRedux (version 0.1)

massfractionation: Apply the mass fractionation correction

Description

Applies the fractionation obtained from air shot data by fractionation to the denominator detector in order to correct it for the mass difference between the numerator and denominator isotopes.

Usage

massfractionation(X, fract)

Arguments

X
an object of class redux
fract
a list with fractionation data for the detectors used to measure the denominator isotopes

Value

  • an object of class redux

Examples

Run this code
data(Melbourne)
C <- calibration(Melbourne$X,"DCAL")
A <- massfractionation(C,Melbourne$fract)
plotcorr(A$covmat)

Run the code above in your browser using DataLab