newredux: Create a new 'redux' object

View source: R/io.R

newreduxR Documentation

Create a new redux object

Description

Initialises a new redux object by packing a logratios dataset together with all the parameters needed for age calculation

Usage

newredux(
  X,
  Jpos,
  detectors = list(Ar36 = "H1", Ar37 = "L2", Ar38 = "L1", Ar39 = "AX", Ar40 = "H1")
)

Arguments

X

an object of class logratios

Jpos

a vector of integers denoting the positions of the fluence monitors in the irradiation stack

detectors

a list of strings denoting the detectors for each argon isotope

Value

an object of class redux


ArArRedux documentation built on July 21, 2026, 1:07 a.m.