This function is used to query and modify the half lives, standard
ages etc. associated with an object of class redux
param(X, ...)returns the modified redux object OR the
current parameter values if no optional arguments are supplied.
an object of class redux
any combination of the parameters given below
param grants access to the following parameters:
l0: 40K decay constant (default value = 5.5492e-4 Ma-1,
Renne et al. [2010])
sl0: standard error of the 40K decay constant (default value
= 0.0047e-4 Ma-1)
l7: 37Ar decay constant (default value = 7.2438 yr-1, Renne
and Norman [2001])
sl7: standard error of the 37Ar decay constant (default
value = 0.0083 yr-1)
l9: 39Ar decay constant (0.002577 yr-1 Stoenner et
al. [1965])
sl9: standard error of the 39Ar decay constant (0.000014
yr-1)
l6: 36Cl decay constant (default value = 2301.3e-9 yr-1)
sl6: standard error of the 36Cl decay constant (default
value = 7.6e-9 yr-1
pcl: (36Cl/38Cl)-production rate (default value = 252.7 for
OSTR reactor, Renne et al. [2008])
spcl: standard error of the (36Cl/38Cl)-production rate
(default value = 1.8)
ts: age of the fluence monitor (default = 28.201 Myr for the
Fish Canyon Tuff, Kuiper et al. [2008])
sts: standard error of the fluence monitor age (default
value = 0.023 Myr)
air: atmospheric 40Ar/36Ar ratio (default value = 298.56,
Lee et al. [2006])
sair: standard error of the atmospheric 40Ar/36Ar ratio
(default value = 0.155)
data(Melbourne)
param(Melbourne$X)$air
Y <- param(Melbourne$X,air=295.5)
param(Y)$air
Run the code above in your browser using DataLab