| plotcorr | R Documentation |
Converts the covariance matrix to a correlation matrix and plots this is a coloured image for visual inspection.
plotcorr(X)
X |
a data structure (list) containing an item called ‘covmat’ (covariance matrix) |
data(Melbourne)
plotcorr(Melbourne$X)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.