read: Read mass spectrometer data

View source: R/io.R

readR Documentation

Read mass spectrometer data

Description

Reads raw mass spectrometer data and parses it into a redux format for further processing.

Usage

read(
  xfile,
  masses,
  blabel,
  Jpos,
  kfile = NULL,
  cafile = NULL,
  dfile = NULL,
  dlabels = NULL,
  MS = "ARGUS-VI"
)

Arguments

xfile

a .csv file with samples and fluence monitor data

masses

a list which specifies the order in which the isotopes are recorded by the mass spectrometer

blabel

a prefix string denoting the blanks

Jpos

a vector of integers denoting the positions of the fluence monitors in the irradiation stack

kfile

a .csv file with the K-interference monitor data (optional)

cafile

a .csv file with the Ca-interference monitor data (optional)

dfile

a .csv file with the detector calibration data (optional)

dlabels

a list which specifies the names of the detectors and the order in which they were recorded by the mass spectrometer

MS

a string denoting the type of mass spectrometer. At the moment only the ARGUS-IV is listed. Please contact the author to add other file formats to Ar-Ar_Redux.

Value

an object of class redux.

Examples

samplefile <-  system.file("Samples.csv",package="ArArRedux")
kfile <- system.file("K-glass.csv",package="ArArRedux")
cafile <- system.file("Ca-salt.csv",package="ArArRedux")
dfile <- system.file("Calibration.csv",package="ArArRedux")
masses <- c("Ar37","Ar38","Ar39","Ar40","Ar36")
dlabels <- c("H1","AX","L1","L2")
X <- read(samplefile,masses,blabel="EXB#",Jpos=c(3,15),
          kfile,cafile,dfile,dlabels)
plotcorr(X)

ArArRedux documentation built on July 21, 2026, 1:07 a.m.

Related to read in ArArRedux...