Learn R Programming

ArArRedux (version 1.1)

subset.timeresolved: Select a subset of some data

Description

Extracts those intercepts, covariances etc. that match a given list of indices or labels.

Usage

# S3 method for timeresolved
subset(x, i = NULL, labels = NULL, invert = FALSE, include.J = FALSE, ...)

# S3 method for logratios subset(x, i = NULL, labels = NULL, invert = FALSE, include.J = FALSE, ...)

# S3 method for redux subset(x, i = NULL, labels = NULL, invert = FALSE, include.J = FALSE, ...)

# S3 method for results subset(x, i = NULL, labels = NULL, invert = FALSE, ...)

Value

an object of the same class as x

Arguments

x

an object of class timeresolved, logratios, redux or results

i

a vector with indices of the selected runs

labels

a string or a vector of strings with sample names

invert

boolean flag indicating whether the selection should be inverted, i.e. whether the selected indices or labels should be removed rather than retained

include.J

if TRUE, automatically adds the irradiation monitors to the selection

...

other arguments

Examples

Run this code
data(Melbourne)
ages <- process(Melbourne$X,Melbourne$irr,Melbourne$fract)
MD <- subset(ages,labels=c("MD2-1","MD2-2","MD2-3","MD2-4","MD2-5"))
plotcorr(MD)

Run the code above in your browser using DataLab