Learn R Programming

ArArRedux (version 1.1)

timeresolved: The timeresolved class

Description

An object class containing time resolved multi-collector mass spectrometry data

Arguments

Details

A list with the following items:

masses: a vector of strings denoting the isotopes monitored in each run
irr: a vector of strings denoting the irradiation runs
pos: a vector of integers with the positions in the irradiation stack
thedate: a vector containing the acquisition dates and times
d: a data table
thetime: a matrix with the measurement times

See Also

loaddata