Learn R Programming

ArArRedux (version 1.1)

averagebyday: Average all the data collected on the same day.

Description

This function is useful for grouping a number of replicate air shots or calibration experiments

Usage

averagebyday(x, newlabel)

Value

an object of the same class as x

Arguments

x

an object of class timeresolved, logratios, PHdata or redux

newlabel

a string with the new label that should be given to the average

Examples

Run this code
dfile <- system.file("Calibration.csv",package="ArArRedux")
dlabels <- c("H1","AX","L1","L2")
md <- loaddata(dfile,dlabels,PH=TRUE)
ld <- fitlogratios(blankcorr(md))
d <- averagebyday(ld,"DCAL")
plotcorr(d)

Run the code above in your browser using DataLab