| newredux | R Documentation |
redux objectInitialises a new redux object by packing a
logratios dataset together with all the parameters
needed for age calculation
newredux(
X,
Jpos,
detectors = list(Ar36 = "H1", Ar37 = "L2", Ar38 = "L1", Ar39 = "AX", Ar40 = "H1")
)
X |
an object of class |
Jpos |
a vector of integers denoting the positions of the fluence monitors in the irradiation stack |
detectors |
a list of strings denoting the detectors for each argon isotope |
an object of class redux
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.