Learn R Programming

ArArRedux (version 1.1)

plotcorr: Plot a matrix with correlation coefficients

Description

Converts the covariance matrix to a correlation matrix and plots this is a coloured image for visual inspection.

Usage

plotcorr(X)

Arguments

X

a data structure (list) containing an item called `covmat' (covariance matrix)

Examples

Run this code
data(Melbourne)
plotcorr(Melbourne$X)

Run the code above in your browser using DataLab