powered by
Converts the covariance matrix to a correlation matrix and plots this is a coloured image for visual inspection.
plotcorr(X)
a data structure (list) containing an item called `covmat' (covariance matrix)
data(Melbourne) plotcorr(Melbourne$X)
Run the code above in your browser using DataLab