| weightedmean | R Documentation |
Computes the error weighted mean and MSWD of some samples taking into covariances.
weightedmean(ages, prefix = NULL)
ages |
an object of class |
prefix |
is either a string with the prefix of the samples that need to be averaged, or a vector of sample names. |
a list with items:
avgt: the weighted mean age
err: the standard error of avgt
MSWD: the Mean Square of the Weighted Deviates
data(Melbourne)
ages <- process(Melbourne$X,Melbourne$irr,Melbourne$fract)
weightedmean(ages,"MD2-")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.